import { ReactNode } from 'react';
import { ButtonProps, DialogProps as EDSDialogProps } from '@equinor/eds-core-react';
import { IconData } from '@equinor/eds-icons';
/**
 * @param position - Right is default
 * @param onClick - button on click
 * @param text - button text
 * @param variant - button variant
 * @param icon - button icon, is placed to the left of the text
 * @param disabled - if set to string, the button is disabled and gets a tooltip
 */
export interface DialogAction {
    position?: 'left' | 'center' | 'right';
    onClick: () => void;
    text: string;
    variant?: ButtonProps['variant'];
    color?: ButtonProps['color'];
    icon?: IconData;
    disabled?: boolean | string;
}
export interface DialogProps extends Omit<EDSDialogProps, 'title'> {
    title: string | ReactNode | [ReactNode, ReactNode];
    children: string | ReactNode | ReactNode[];
    onClose: () => void;
    width?: number;
    actions?: DialogAction[];
    withContentPadding?: boolean;
    withBorders?: boolean;
}
/**
 * @param title - String or up to 2 react elements in a flex-column
 * @param children - Content in the dialog, if string it gets the default typography styling for dialogs
 * @param onClose - fn to set open to false
 * @param width - width in px, defaults to just fit-content
 * @param actions - Dialog actions, { position: "right" is default }
 * @param withContentPadding - Defaults to true
 * @param withBorders - Defaults to false
 * Also inherits props from EDS dialog
 */
export declare const Dialog: import("react").ForwardRefExoticComponent<DialogProps & import("react").RefAttributes<HTMLDivElement>>;
